/**
 * @module dixim
 * @submodule autoDownload
 */
dixim.namespace('dixim.autoDownload');

/**
 * @module autoDownload
 * @submodule cond-dialog-view
 */

(function() {
var CondDialogView;
var prototype;
var superConstructor;
var _ = dixim.ctt.ResourceBundle.get;
var Event = dixim.event.Event;
var ModalDialogView = dixim.common.ModalDialogView;
var Enum = dixim.ctt.util.Enum;
var PlaceHolder = dixim.ctt.util.PlaceHolder;
var Utils = dixim.ctt.util.Utils;
var UiUtils = dixim.common.UiUtils;
var $ = dixim.ctt.jQuery;

/**
 * @class CondDialogView
 * @constructor
 * @param {Object} configs
 */
CondDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(CondDialogView, ModalDialogView);
dixim.autoDownload.CondDialogView = CondDialogView;
prototype = CondDialogView.prototype;
superConstructor = CondDialogView.superConstructor;

var NO_COND = 'noCond';
var SETTING = 'setting';

var COND = Enum.fetch('COND');

var TEMPLATE_BODY_CONTENT = [
    '<div id="auto-download-cond-field">', '</div>',
].join('');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'cond-dialog-'].join('');

    this._condId = configs.condId;

    configs.bodyContent = TEMPLATE_BODY_CONTENT;
    configs.doubleDialog = true;
    configs.contentHeight = configs.contentHeight || 'auto';
    configs.buttons = [
        {text: _('dialog_cancel'), click: dixim.proxy(this.hide, this)},
        {text: _('dialog_no_cond'), click: dixim.proxy(this._clickNoCond, this)},
        {text: _('dialog_setting'), click: dixim.proxy(this._clickSetting, this)},
    ];
    configs.title = _(['auto_download_filter_edit_condition_', this._condId].join(''));

    this._cpConds = [];

    superConstructor.prototype._initialize.call(this, configs);
};

prototype._render = function() {
    var genres = [
        _('auto_download_cond_genre_1'),
        _('auto_download_cond_genre_2'),
        _('auto_download_cond_genre_4'),
        _('auto_download_cond_genre_8'),
        _('auto_download_cond_genre_16'),
        _('auto_download_cond_genre_32'),
        _('auto_download_cond_genre_64'),
        _('auto_download_cond_genre_128'),
        _('auto_download_cond_genre_256'),
        _('auto_download_cond_genre_512'),
        _('auto_download_cond_genre_1024'),
        _('auto_download_cond_genre_2048'),
        _('auto_download_cond_genre_4096'),
    ];
    var genres_length = genres.length;
    var dayOfTheWeek = [
        _('auto_download_cond_day_sunday'),
        _('auto_download_cond_day_monday'),
        _('auto_download_cond_day_tuesday'),
        _('auto_download_cond_day_wednesday'),
        _('auto_download_cond_day_thursday'),
        _('auto_download_cond_day_friday'),
        _('auto_download_cond_day_saturday')
    ];
    var dayOfTheWeekLen = dayOfTheWeek.length;
     var duration = [
        _('auto_download_cond_duration_long'),
        _('auto_download_cond_duration_short'),
        _('auto_download_cond_duration_equal')
    ];
    var durationLen = duration.length;
    var broadcast = [
        _('auto_download_cond_broadcast_td'),
        _('auto_download_cond_broadcast_bs'),
        _('auto_download_cond_broadcast_cs'),
        _('auto_download_cond_broadcast_sptv'),
        _('auto_download_cond_broadcast_catv'),
        _('auto_download_cond_broadcast_iptv')
    ];
    var broadcaseLen = broadcast.length;
    var copyCountText;
 
    switch(this._condId) {
        case COND.TITLE:
        case COND.CHANNEL:
        case COND.DESCRIPTION:
        case COND.DATE:
            $('#auto-download-cond-field').html(['<table id="auto-download-default-cond">', '</table>' ].join(''));
            $('#auto-download-cond-field').addClass('auto-download-default-cond-list');
            this.addDefaultList();
            break;
        case COND.GENRE:
            $('#auto-download-cond-field').html(['<div id="auto-download-genre-cond">', '</div>'].join(''));
            for (var i = 0; i < genres_length; i += 1) {
                $('#auto-download-genre-cond').append([
                    '<label class="select-pointer">',
                    '<input type="checkbox" id="', Math.pow(2, i), '" value="', Math.pow(2, i), '" />',
                    '<span>', genres[i], '</span>',
                    '</label>',
                ].join(''));
            }
            $('#auto-download-genre-cond [type="checkbox"]').on('click', this, this._checkGenreSetting);
            break;
        case COND.DAY:
            $('#auto-download-cond-field').html(['<div id="auto-download-day-of-the-week-cond">', '</div>' ].join(''));
            for (var i = 0; i < dayOfTheWeekLen; i += 1) {
                $('#auto-download-day-of-the-week-cond').append([
                    '<label class="select-pointer">',
                    '<input type="checkbox" id="', Math.pow(2, i), '" value="', Math.pow(2, i), '" />',
                    '<span>', dayOfTheWeek[i], '</span>',
                    '</label>',
                ].join(''));
            }
            $('#auto-download-day-of-the-week-cond [type="checkbox"]').on('click', dixim.proxy(this._checkDaySetting, this));
            break;
        case COND.DURATION:
            $('#auto-download-cond-field').html(['<table id="auto-download-duration-cond">', '</table>' ].join(''));
            for (var i = 0 ; i < durationLen; i += 1) {
                $('#auto-download-duration-cond').append([
                    '<tr>', '<td class="check-cell">',
                    '<label class="select-pointer">', '<input type="checkbox" id="', i, '" />', '<span>', '</span>', '</label>',
                    '</td>', '<td class="time-cell">',
                    '<input type="text" class="time-text-field" name="hour" maxlength="2" pattern="[0-9]*" disabled />', _('auto_download_cond_hour'),
                    '<input type="text" class="time-text-field" name="min" maxlength="2" pattern="[0-9]*" disabled />', _('auto_download_cond_min'),
                    '<span class="time-text-cell">', duration[i], '</span>',
                    '</td>', '</tr>',
                ].join(''));

                if(i === 2) {
                    $('#auto-download-duration-cond tr:last-child .time-cell').append([
                        '<div class="error-text-cell ib">',
                        '<label class="error-cell">',
                        _('auto_download_cond_duration_error'),
                        '<input type="text" name="error" class="time-text-field" maxlength="2" pattern="[0-9]*" disabled />',
                        _('auto_download_cond_duration_minute'),
                        '</label>',
                        '</div>',
                    ].join(''));
                } else {
                    $('#auto-download-duration-cond tr:last-child span.time-text-cell').prop('colspan', '4');
                }
            }
            $('#auto-download-duration-cond #0').prop('id', '11');
            $('#auto-download-duration-cond #1').prop('id', '9');
            $('#auto-download-duration-cond #2').prop('id', '7');
            $('#auto-download-duration-cond [type="checkbox"]').on('click', this._checkDurationRecordingCheckbox);
            $('#auto-download-duration-cond [type="checkbox"]').on('click', dixim.proxy(this._checkDurationSetting, this));
            $('#auto-download-duration-cond input').on('keyup change', dixim.proxy(this._checkDurationSetting, this));
            break;
        case COND.START_TIME:
        case COND.END_TIME:
            $('#auto-download-cond-field').html(['<table id="auto-download-', this._condId, '">', '</table>' ].join(''));
            $(['#auto-download-', this._condId].join('')).html([
                '<tr>', '<td class="check-cell">',
                '<label class="select-pointer">', '<input id="recording-check" type="checkbox" />', '<span>', '</span>', '</label>',
                '</td>', '<td class="time-cell">',
                '<input type="text" class="time-text-field" name="hour" maxlength="2" pattern="[0-9]*" disabled />', _('auto_download_cond_hour'),
                '<input type="text" class="time-text-field" name="min" maxlength="2" pattern="[0-9]*" disabled />', _('auto_download_cond_min'),
                '<div class="error-text-cell ib">',
                '<label class="error-cell">',
                _('auto_download_cond_duration_error'),
                '<input type="text" name="error" class="time-text-field" maxlength="2" pattern="[0-9]*" disabled />',
                _('auto_download_cond_duration_minute'),
                '</label>',
                '</td>', '</tr>',
                ].join(''));
        
            $(['#auto-download-', this._condId, ' [type="checkbox"]'].join('')).on('click', this._checkDurationRecordingCheckbox);
            $(['#auto-download-', this._condId, ' [type="checkbox"]'].join('')).on('click', dixim.proxy(this._checkRecordingSetting, this));
            $(['#auto-download-', this._condId, ' input'].join('')).on('keyup change', dixim.proxy(this._checkRecordingSetting, this));
            break;
        case COND.BROADCAST:
            $('#auto-download-cond-field').html(['<div id="auto-download-broadcast-cond">', '</div>' ].join(''));
            for (var i = 0; i < broadcaseLen; i += 1) {
                $('#auto-download-broadcast-cond').append([
                    '<label class="select-pointer">',
                    '<input type="checkbox" id="', Math.pow(2, i), '" value="', Math.pow(2, i), '" />',
                    '<span>', broadcast[i], '</span>',
                    '</label>',
                ].join(''));
            }
            $('#auto-download-broadcast-cond [type="checkbox"]').on('click', dixim.proxy(this._checkBroadcastSetting, this));
            break;
        case COND.COPY_COUNT:
            $('#auto-download-cond-field').html(['<table id="auto-download-copy-count-cond">', '</table>' ].join(''));
            for (var i = 0; i < 3; i += 1) {
                $('#auto-download-copy-count-cond').append([
                    '<tr>', '<td class="check-cell">',
                    '<label class="select-pointer">', '<input type="checkbox" id="', i, '" value="', i, '" />', '<span>', '</span>', '</label>',
                    '</td>', '<td class="select-sell">',
                    '<label class="digit_box3">', '<select class="select-pointer" disabled>', '</select>', '</label>',
                    '</td>', '</tr>',
                ].join(''));
                for (var j = 0; j <= 10; j += 1) {
                    copyCountText = (j === 10) ? _('auto_download_cond_copy_free'): j+1;
                    $('#auto-download-copy-count-cond tr:last-child select').append(['<option value="', j, '">', copyCountText, '</option>' ].join(''));
                }
                switch(i) {
                    case 0:
                        $('#auto-download-copy-count-cond tr:last-child').append([
                            '<td>', '<label class="cond_box">', '<select class="select-pointer" disabled>',
                            '<option value="11">', _('auto_download_cond_more_big'), '</option>',
                            '<option value="12">', _('auto_download_cond_big'), '</option>',
                            '</select>', '</label>', '</td>',
                        ].join(''));
                        break;
                    case 1:
                        $('#auto-download-copy-count-cond tr:last-child').append([
                            '<td>', '<label class="cond_box">',  '<select class="select-pointer" disabled>',
                            '<option value="9">', _('auto_download_cond_more_small'), '</option>',
                            '<option value="10">', _('auto_download_cond_small'), '</option>',
                            '</select>', '</label>', '</td>',
                        ].join(''));
                        break;
                    case 2:
                        $('#auto-download-copy-count-cond tr:last-child').append([
                            '<td>',
                            '<span>', _('auto_download_cond_equal'), '</span>',
                            '</td>',
                        ].join(''));
                        break;
                }
            }
            if (Utils.isUserAgent('ipod') && Utils.isUserAgent('touch')) {
                $('.cond_box, .cond_box select').css('min-width', '100px');
            }
            $('#auto-download-copy-count-cond [type="checkbox"]').on('click', this._checkDurationCopyCountCheckbox);
            $('#auto-download-copy-count-cond [type="checkbox"]').on('click', dixim.proxy(this._checkCopyCountSetting, this));
            break;
    }

    this.disableButton(_('dialog_setting'));
    $('input').on('blur', function() {
        setTimeout(function() {
            $('body').scrollTop($('body').scrollTop() + 1);
            $('body').scrollTop($('body').scrollTop() -  1);
        }, 100);
    });
    superConstructor.prototype._render.call(this);
};

prototype.addDefaultList = function() {
    var condCouplingList = new Array();
    var condCouplingName;
    var brotherId = $('#auto-download-default-cond tr:last-child').prop('id') || 0;
    var rowId = parseInt(brotherId, 10) + 1;
    var rfeCond;

    $('#auto-download-default-cond').append([
        '<tr id="', rowId, '">', '<td>',
        '<input type="text" id="default_text_', rowId, '" class="cond-text" maxlength="255"/>',
        '</td>', '<td>',
        '<label class="cond_box">', '<select id="default_select_', rowId, '" class="select-pointer">', '</select>', '</label>',
        '</td>', '</tr>',
    ].join(''));

    switch(this._condId) {
        case COND.TITLE:
            condCouplingList = ['1', '2', '3', '5', '7', '8', 'del'];
            break;
        case COND.CHANNEL:
            condCouplingList = ['1', '2', '7', '8', 'del'];
            break;
        case COND.DESCRIPTION:
            condCouplingList = ['1', '2', 'del'];
            break;
        case COND.DATE:
            $('#auto-download-default-cond tr:last-child td:first-child').html([
                '<input type="text" class="cond-text placeholder_position"/>',
            ].join(''));
            PlaceHolder.set('#auto-download-default-cond tr:last-child td:first-child .placeholder_position', 'YYYY/MM/DD');
            condCouplingList = ['7', '8', '10', '12', 'del'];
            break;
    }

    for (var i = 0; i < condCouplingList.length; i += 1) {
        condCouplingName = _(['auto_download_cond_select_', condCouplingList[i]].join(''));
        $('#auto-download-default-cond tr:last-child select').append([
            '<option value="', condCouplingList[i], '">', condCouplingName, '</option>',
        ].join(''));
        $('#auto-download-default-cond tr:last-child option:last-child').prop('disabled', (condCouplingList[i] === 'del'));
    }

    if (Utils.isUserAgent('ipod') && Utils.isUserAgent('touch')) {
        $('.cond_box, .cond_box select').css('min-width', '100px');
    }

    if (rowId > 1) {
        rfeCond = new UiUtils.textFocusEvent();
        rfeCond.set(['#default_text_', rowId].join(''), ['#default_text_', rowId-1].join(''));
    }
    this._cpConds[rowId] = new UiUtils.clearPanelOnTextField(['#default_text_', rowId].join(''));
    this._cpConds[rowId].set();
    $('#auto-download-cond-field').scroll(dixim.proxy(function() {
        var cpLen = this._cpConds.length;

        for (var i = 0; i < cpLen; i += 1) {
            if (this._cpConds[i] !== 'undefined') {
                this._cpConds[rowId].reposition();
            }
        }
    }, this));

    $('#auto-download-default-cond tr:last-child input').on('keyup change', this, this._checkAddDefaultList);
    $('#auto-download-default-cond tr:last-child select').on('change', this, this._checkDelDefaultList);
};

prototype._checkAddDefaultList = function(thisModule) {
    var validSetting = true;

    $('#auto-download-default-cond input').each(function() {
        var text = $(this).val();

        if (text !== '') {
            validSetting = false;
            return true;
        }
    });
    if (validSetting) {
        thisModule.data.disableButton(_('dialog_setting'));
    } else {
        thisModule.data.enableButton(_('dialog_setting'));
    }

    if ($(this).val() !== '' && $(this).closest('tr').is('#auto-download-default-cond tr:last-child')) {
        $(this).closest('tr').find('option:last-child').prop('disabled', false);
        thisModule.data.addDefaultList();
    }
};

prototype._checkDelDefaultList = function(thisModule) {
    if ($(this).val() === 'del') {
        if (! $(this).closest('tr').is('#auto-download-default-cond tr:last-child')) {
            $(this).closest('tr').remove();
            if ($('#auto-download-default-cond tr').length === 1) {
                thisModule.data.disableButton(_('dialog_setting'));
            }
        }
    }
};

prototype.setCondsDefault = function(info) {
    var infoLen = info.length;
    var infoDateValue;
    var date;

    for(var i = 0; i < infoLen; i += 1) {
        if (this._condId === COND.DATE) {
            date = info[i].value.split('/');
            date = date.join('');
            infoDateValue = date.substr(0, 4);
            infoDateValue = [infoDateValue, '/'].join('');
            infoDateValue = [infoDateValue, date.substr(4, 2)].join('');
            infoDateValue = [infoDateValue, '/'].join('');
            infoDateValue = [infoDateValue, date.substr(6, 2)].join('');
            info[i].value = infoDateValue;
        }
        $('#auto-download-default-cond tr:last-child select').val(info[i].op);
        $('#auto-download-default-cond tr:last-child input').val(info[i].value).trigger('change');
    }
};

prototype._getDefaultList = function() {
    var info = [];
    var condId = this._condId;

    if (this._condId === COND.DATE) {
        $('#auto-download-default-cond tr').not(':last-child').each(function() {
            var inputDate = $(this).find('input').val();
            var year = null;
            var month = null;
            var day = null;
            var date = null;

            if ($(this).find('input').hasClass('placeholding')) {
                return true;
            }
            if (! inputDate.match(/^\d{4}\/\d{1,2}\/\d{1,2}$/)) {
                date = 'error';
            } else {
                inputDate = inputDate.split('/');
                year = parseInt(inputDate[0], 10);
                month = parseInt(inputDate[1], 10);
                day = parseInt(inputDate[2], 10);
                date = new Date(year, month - 1, day);
                if (date.getFullYear() !== year || date.getMonth() !== month - 1 || date.getDate() !== day) {
                    date = 'error';
                }
            }
            if (date === 'error') {
                info.push({
                    name: condId,
                    value: 'error',
                });
                return true;
            } else {
                date = [year, ('00' + month).slice('-2'), ('00' + day).slice('-2')].join('');
            }
            if ($(this).find('input').val() !== '') {
            info.push({
                name: condId,
                value: date,
                op: parseInt($(this).find('select').val(), 10),
            });
            }
        });
    } else {
        $('#auto-download-default-cond tr').each(function() {
            if ($(this).find('input').val() !== '') {
                info.push({
                    name: condId,
                    value: $(this).find('input').val(),
                    op: parseInt($(this).find('select').val(), 10),
                });
            }
        });
    }

    return info;
};

prototype._checkGenreSetting = function(thisModule) {
    var checkedLen = $('#auto-download-genre-cond [type="checkbox"]:checked').length;

    if (checkedLen) {
        thisModule.data.enableButton(_('dialog_setting'));
    } else {
        thisModule.data.disableButton(_('dialog_setting'));
    }
};

prototype.setCondsGenre = function(info) {
    var num;

    if (typeof info[0] !== 'undefined') {
        num = parseInt(info[0].value, 10);
        for (var i = 4096;i > 0;i /= 2) {
            if (i <= num) {
                $(['#auto-download-genre-cond input#', i].join('')).trigger('click');
                num -= i;
            }
        }
    }
};

prototype._getGenreList = function() {
    var info = [];
    var condId = this._condId;
    var checkValue = 0;

    $('#auto-download-genre-cond :checked').each(function() {
        checkValue += parseInt($(this).val());
    });
    info.push({
        name: condId,
        value: checkValue,
        op: 1,
    });
    return info;
};

prototype._checkDaySetting = function() {
    var checkedLen = $('#auto-download-day-of-the-week-cond [type="checkbox"]:checked').length;

    if (checkedLen) {
        this.enableButton(_('dialog_setting'));
    } else {
        this.disableButton(_('dialog_setting'));
    }
};

prototype.setCondsDay = function(info) {
    var num;

    if (typeof info[0] !== 'undefined') {
        num = parseInt(info[0].value, 10);
        for ( var i = 64; i > 0; i /= 2 ) {
            if (i <= num) {
                $(['#auto-download-day-of-the-week-cond input#', i].join('')).trigger('click');
                num -= i;
            }
        }
    }
};

prototype._getDayList = function() {
    var info = [];
    var checkValue = 0;

    $('#auto-download-day-of-the-week-cond :checked').each(function() {
        checkValue += parseInt($(this).val(), 10);
    });
    info.push({
        name: 8,
        value: checkValue,
        op: 1,
    });
    return info;
};

prototype._checkDurationRecordingCheckbox = function() {
    $(this).closest('tr').find('[type="text"]').prop('disabled', (! $(this).is(':checked')));
    if (! $(this).is(':checked')) {
        $(this).closest('tr').find('[type="text"]').val('');
    }
};

prototype._checkRecordingSetting = function() {
    var hour;
    var min;
    var error;

    $.each($('input[name="hour"]'), function() {
        var hour = $(this).val();

        if (!(hour.match(/^\d{1,2}$/) && hour <= 23)) $(this).val('');
    });
    $.each($('input[name="min"]'), function() {
        var min = $(this).val();

        if (!(min.match(/^\d{1,2}$/) && min < 60)) $(this).val('');
    });
    $.each($('input[name="error"]'), function() {
        var error = $(this).val();

        if (!(error.match(/^\d{1,2}$/))) $(this).val('');
    });

    hour = $(['#auto-download-', this._condId, ' [name="hour"]'].join('')).val();
    min = $(['#auto-download-', this._condId, ' [name="min"]'].join('')).val();
    error = $(['#auto-download-', this._condId, ' [name="error"]'].join('')).val();

    if((hour !== '') && (min !== '') && (error !== '')) {
        this.enableButton(_('dialog_setting'));
    } else {
        this.disableButton(_('dialog_setting'));
    }
};

prototype._checkDurationRecordingCheckbox = function() {
    $(this).closest('tr').find('[type="text"]').prop('disabled', (! $(this).is(':checked')));
    if (! $(this).is(':checked')) {
        $(this).closest('tr').find('[type="text"]').val('');
    }
};

prototype.setCondsRecording = function(info) {
    var recordingInfo;
    var recordingHour;
    var recordingMinute;
    var recordingError;

    if (info.length !== 0) {
        recordingInfo = info[0];
        recordingHour = ('00' + Math.floor(recordingInfo.value / 60)).slice('-2');
        recordingMinute = ('00' + recordingInfo.value % 60).slice('-2');
        recordingError = recordingInfo.value2;
        $('#auto-download-cond-field #recording-check').trigger('click');
        $(['#auto-download-', this._condId, ' [name="hour"]'].join('')).val(recordingHour);
        $(['#auto-download-', this._condId, ' [name="min"]'].join('')).val(recordingMinute);
        $(['#auto-download-', this._condId, ' [name="error"]'].join('')).val(recordingError);
    }
};

prototype._getRecordingList = function() {
    var info = [];
    var recordingHour = $(['#auto-download-', this._condId, ' [name="hour"]'].join('')).val();
    var recordingMinute = $(['#auto-download-', this._condId, ' [name="min"]'].join('')).val();
    var recordingError = $(['#auto-download-', this._condId, ' [name="error"]'].join('')).val();
    var recordingTime = parseInt(recordingHour, 10) * 60 + parseInt(recordingMinute, 10);
    var recordingError = parseInt(recordingError, 10);

    if (recordingError < 0) return true;
    info.push({
        name: this._condId,
        value: recordingTime,
        value2: recordingError,
        op: 7,
    });

    return info;
};

prototype._checkDurationSetting = function() {
    var longerHour;
    var longerMinute;
    var checkLongerTime;
    var shorterHour;
    var shorterMinute;
    var checkShorterTime;
    var equalHour;
    var equalMinute;
    var error;
    var checkEqualTime;

    $.each($('input[name="hour"]'), function() {
        var hour = $(this).val();

        if (!(hour.match(/^\d{1,2}$/) && hour <= 23)) $(this).val('');
    });
    $.each($('input[name="min"]'), function() {
        var min = $(this).val();

        if (!(min.match(/^\d{1,2}$/) && min < 60)) $(this).val('');
    });
    $.each($('input[name="error"]'), function() {
        var error = $(this).val();

        if (!(error.match(/^\d{1,2}$/))) $(this).val('');
    });

    longerHour = $('#auto-download-duration-cond #11').closest('tr').find('[name="hour"]').val();
    longerMinute = $('#auto-download-duration-cond #11').closest('tr').find('[name="min"]').val();
    shorterHour = $('#auto-download-duration-cond #9').closest('tr').find('[name="hour"]').val();
    shorterMinute = $('#auto-download-duration-cond #9').closest('tr').find('[name="min"]').val();
    equalHour = $('#auto-download-duration-cond #7').closest('tr').find('[name="hour"]').val();
    equalMinute = $('#auto-download-duration-cond #7').closest('tr').find('[name="min"]').val();
    error = $('#auto-download-duration-cond [name="error"]').val();
    checkLongerTime = (longerHour !== '') && (longerMinute !== '');
    checkShorterTime = (shorterHour !== '') && (shorterMinute !== '');
    checkEqualTime = (equalHour !== '') && (equalMinute !== '') && (error !== '');

    if ((checkLongerTime) || (checkShorterTime) || (checkEqualTime)) {
        this.enableButton(_('dialog_setting'));
    } else {
        this.disableButton(_('dialog_setting'));
    }

};

prototype.setCondsDuration = function(info) {
    var infoLen = info.length;
    var hour;
    var min;

    for(var i = 0; i < infoLen; i+= 1) {
        hour = Math.floor(info[i].value / 1000 / 60 / 60);
        min = info[i].value / 1000 / 60 % 60;
        $(['#auto-download-duration-cond input#', info[i].op].join('')).trigger('click');
        $(['#auto-download-duration-cond input#', info[i].op].join('')).closest('tr').find('[name="hour"]').val(hour);
        $(['#auto-download-duration-cond input#', info[i].op].join('')).closest('tr').find('[name="min"]').val(min);
        if (parseInt(info[i].op, 10) === 7) {
            $(['#auto-download-duration-cond input#', info[i].op].join('')).closest('tr').find('[name="error"]').val(info[i].value2 / 1000 / 60);
        }
    }
};

prototype._getDurationList = function() {
    var info = [];

    $('#auto-download-duration-cond :checked').each(function() {
        var id;
        var time;
        var hourText = $(this).closest('tr').find('[name="hour"]').val();
        var minuteText = $(this).closest('tr').find('[name="min"]').val();
        var timeErrorText = $(this).closest('tr').find('[name="error"]').val();
        var durationInfo = {};

        if (hourText === '' || minuteText === '') return true;

        id = parseInt($(this).prop('id'), 10);
        time = (parseInt(hourText, 10) * 60 * 60 * 1000) + (parseInt(minuteText, 10) * 60 * 1000);
        durationInfo.name = 5;
        durationInfo.value = time;
        durationInfo.op = id;
    
        if (id === 7) {
            if (timeErrorText === '' || timeErrorText < 0) return true;

            durationInfo.value2 = parseInt(timeErrorText, 10) * 60 * 1000;
        }
        info.push(durationInfo);
    });
    return info;
};

prototype._checkDurationCopyCountCheckbox = function() {
    $(this).closest('tr').find('select').prop('disabled', (! $(this).is(':checked')));
};

prototype._checkBroadcastSetting = function() {
    var checkedLen = $('#auto-download-broadcast-cond [type="checkbox"]:checked').length;

    if (checkedLen) {
        this.enableButton(_('dialog_setting'));
    } else {
        this.disableButton(_('dialog_setting'));
    }
};

prototype.setCondsBroadcast = function(info) {
    var num;

    if (typeof info[0] !== 'undefined') {
        num = parseInt(info[0].value, 10);
        for ( var i = 32; i > 0; i /= 2 ) {
            if (i <= num) {
                $(['#auto-download-broadcast-cond input#', i].join('')).trigger('click');
                num -= i;
            }
        }
    }
};

prototype._getBroadcastList = function() {
    var info = [];
    var checkValue = 0;

    $('#auto-download-broadcast-cond :checked').each(function() {
        checkValue += parseInt($(this).val());
    });
    info.push({
        name: 11,
        value: checkValue,
        op: 1,
    });
    return info;
};

prototype._checkCopyCountSetting = function() {
    var checkedLen = $('#auto-download-copy-count-cond [type="checkbox"]:checked').length;

    if (checkedLen) {
        this.enableButton(_('dialog_setting'));
    } else {
        this.disableButton(_('dialog_setting'));
    }
};

prototype.setCondsCopyCount = function(info) {
    var infoLen = info.length;
    var id = '';

    for (var i = 0; i < infoLen; i += 1) {
        switch(info[i].op) {
        case 11:
        case 12:
            id = '#auto-download-copy-count-cond #0';
            break;
        case 9:
        case 10:
            id = '#auto-download-copy-count-cond #1';
            break;
        case 7:
            id = '#auto-download-copy-count-cond #2';
            break;
        }
        $(id).trigger('click');
        $(id).closest('tr').find('.select-sell').find('select').val(info[i].value);
        if (info[i].op !== 7) $(id).closest('tr').find('td:last-child select').val(info[i].op);
    }
};

prototype._getCopyCountList = function() {
    var info = [];

    $('#auto-download-copy-count-cond [type="checkbox"]:checked').each(function() {
        var id = $(this).val();
        var copyCountInfo = {};

        copyCountInfo.name = 6;
        copyCountInfo.value = $(this).closest('tr').find('.select-sell').find('select').val();
        if (id !== '2') {
            copyCountInfo.op = parseInt($(this).closest('tr').find('td:last-child select').val(), 10);
        } else {
            copyCountInfo.op = 7;
        }
        info.push(copyCountInfo);
    });
    return info;
};

prototype._clickNoCond = function() {
    this.dispatchEvent(new Event(NO_COND, {condId: this._condId}));
};

prototype._clickSetting = function() {
    var info;

    switch(this._condId) {
        case COND.TITLE:
        case COND.CHANNEL:
        case COND.DESCRIPTION:
        case COND.DATE:
            info = this._getDefaultList();
            break;
        case COND.GENRE:
            info = this._getGenreList();
            break;
        case COND.DAY:
            info = this._getDayList();
            break;
        case COND.DURATION:
            info = this._getDurationList();
            break;
        case COND.START_TIME:
        case COND.END_TIME:
            info = this._getRecordingList();
            break;
        case COND.BROADCAST:
            info = this._getBroadcastList();
            break;
        case COND.COPY_COUNT:
            info = this._getCopyCountList();
            break;
    }
    this.dispatchEvent(new Event(SETTING, info));
};

}());
