/**
 * @module dixim
 * @submodule contents
 */
dixim.namespace('dixim.contents');

/**
 * @module contents
 * @submodule transfer-history-dialog-view
 */

(function() {
var TransferHistoryDialogView;
var prototype;
var superConstructor;
var Event = dixim.event.Event;
var ModalDialogView = dixim.common.ModalDialogView;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;
var Formatter = dixim.ctt.util.Formatter;
var Configs = dixim.ctt.Configs;

/**
 * @class TransferHistoryDialogView
 * @extends ModalDialogView
 * @constructor
 * @param {Object} configs
 */
TransferHistoryDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(TransferHistoryDialogView, ModalDialogView);
dixim.contents.TransferHistoryDialogView = TransferHistoryDialogView;
prototype = TransferHistoryDialogView.prototype;
superConstructor = TransferHistoryDialogView.superConstructor;

var TEMPLATE_BODY_CONTENT = [
    '<div class="ctt-transfer-history-view none_margin_top dlg_scroll">',
    '<table id="ctt-transfer-history-list">',
    '<colgroup>',
    '<col span="1" class="list_info">', '<col span="1" class="list_status">',
    '</colgroup>',
    '</table>',
    '</div>',
].join('');

var CLEAR = 'clear';

prototype._initialize = function(configs) {
    configs  = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'transfer-history-dialog-'].join('');

    configs.buttons = [
    {
        text: _('dialog_return_menu'),
        click: dixim.proxy(this.hide, this)
    },
    {
        text: _('dialog_history_delete'),
        click: dixim.proxy(this._clickClear, this)
    }
    ];

    configs.title = _('contents_setting_menu_transfer_history');
    configs.bodyContent = TEMPLATE_BODY_CONTENT;
    configs.contentHeight = '300px';
    configs.doubleDialog = true;

    this._direction = configs.direction;

    superConstructor.prototype._initialize.call(this, configs);
};

prototype.addTransferHistoryList = function(res, id) {
    var date = Formatter.stringifyDate(Formatter.dcDateToDate(res.date), 'YYYY/MM/DD hh/mm/ss');
    var imgSrc = '';

    $('#ctt-transfer-history-list').append([
        '<tbody id="history-', id, '" class="history-list">',
        '<tr>', '<td class="transfer-history-title-field">',
        '<span class="list_title_s">', '</span>',
        '<div class="list_detail txt_s" >',
        '<dl class="list_4em">',
        '<dt>', (this._direction === 'upload') ? _('contents_transfer_history_dialog_server') : _('contents_transfer_history_dialog_src_server'), ' : ', '</dt>',
        '<dd>', '<p>', '<span id="history-server" class="history-description">', '</span>', '</p>', '</dd>',
        '<dt>', _('contents_transfer_history_dialog_date'), ' : ', '</dt>',
        '<dd>', '<p>', '<span class="history-description">', date, '</span>', '</p>', '</dd>',
        '</dl>',
        '</div>',
        '</td>','<td class="transfer-history-status">',
        '<div class="st_dlok">',
        '<img id="history-img-', id, '" width="40px" />',
        '<span id="transfer-status">', '</span>',
        '</div>',
        '</td>', '</tr>',
        '</tbody>',
    ].join(''));
    $(['#history-', id, ' .list_title_s'].join('')).text(res.title);
    $(['#history-', id, ' #history-server'].join('')).text(res.server);

    switch(res.status) {
    case '0':
        imgSrc = [Configs.get('imagePath'), '/ico_st_ok.png'].join('');
        $(['#history-', id, ' .transfer-history-status'].join('')).addClass('color_green');
        $(['#history-', id, ' #transfer-status'].join('')).append(_('contents_transfer_history_dialog_success'));
        break;
    case '1':
        imgSrc = [Configs.get('imagePath'), '/ico_st_error.png'].join('');
        $(['#history-', id, ' .transfer-history-status'].join('')).addClass('color_red');
        $(['#history-', id, ' #transfer-status'].join('')).append(_('contents_transfer_history_dialog_fail'));
        break;
    default:
        imgSrc = [Configs.get('imagePath'), '/ico_st_error.png'].join('');
        $(['#history-', id, ' .transfer-history-status'].join('')).addClass('color_red');
        $(['#history-', id, ' #transfer-status'].join('')).append(_('contents_transfer_history_dialog_error'));
        break;
    }
    $(['#history-img-', id].join('')).prop('src', imgSrc);
};

prototype.addNoContents = function() {
    this.error(_('contents_transfer_history_dialog_no_content'));
};

prototype.disableClearButton = function() {
    this.disableButton(_('dialog_history_delete'));
};

prototype.error =  function(text) {
    $('.ctt-transfer-history-view').html([
        '<div class="txt_none error-text-field">', '<span>', text, '</span>', '</div>',
    ].join(''));
};

prototype._clickClear = function() {
    this.dispatchEvent(new Event(CLEAR));
};

prototype.clearHistoryList = function() {
    $('#ctt-transfer-history-list').empty();
};

}());
