/**
 * @module dixim
 * @submodule contents
 */
dixim.namespace('dixim.contents');

/**
 * @module contents
 * @submodule transfer-wizard-status-dialog-view
 */

(function() {
var TransferWizardStatusDialogView;
var prototype;
var superConstructor;
var ModalDialogView = dixim.common.ModalDialogView;
var ProgressBar = dixim.common.ProgressBar;
var _ = dixim.ctt.ResourceBundle.get;
var Event = dixim.event.Event;
var $ = dixim.ctt.jQuery;

/**
 * @class TransferWizardStatusDialogView
 * @constructor
 * @param {Object} configs
 */
TransferWizardStatusDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(TransferWizardStatusDialogView, ModalDialogView);
dixim.contents.TransferWizardStatusDialogView = TransferWizardStatusDialogView;
superConstructor = TransferWizardStatusDialogView.superConstructor;
prototype = TransferWizardStatusDialogView.prototype;

var CANCEL = 'cancel';
var TEMPLATE_BODY_CONTENT = [
    '<div id="status-description-field" class="dlg_main_msg">', '</div>',
].join('');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    var srcType;
    var dstType;

    configs = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'transfer-wizard-status-dialog-'].join('');

    configs.title = _('contents_operation_menu_transfer');

    srcType = configs.srcType || '';
    dstType = configs.dstType || '';
    if ((srcType === 'local') && (dstType === 'network')) {
        configs.title = _('contents_operation_menu_transfer');
    }

    configs.bodyContent = TEMPLATE_BODY_CONTENT;

    configs.doubleDialog = (typeof configs.doubleDialog === 'undefined') ? true : configs.doubleDialog;
    configs.contentHeight = configs.contentHeight || 'auto';
    configs.buttons = [
        {text: _('dialog_cancel'), click: dixim.proxy(this._clickCancel, this)},
    ];

    this._progressBar = new ProgressBar({descriptionFlag: true});

    superConstructor.prototype._initialize.call(this, configs);
};

prototype.showWaitingView = function() {
    $('#status-description-field').html([
        '<span>', _('contents_wizard_status_start_waiting'), '</span>',
    ].join(''));
};

prototype.setStatusDescription = function(str, isBorder, isError) {
    $('#status-description-field').html([
        '<span>', str, '</span>',
    ].join(''));

    if (isBorder) {
        $('#status-fields').css('border-top', '1px solid #bdbdbd');
    }

    if (isError) {
        $('#status-description-field span').addClass('error-text');
    }
};

prototype.addContent = function(id, name) {
    if ($('#status-fields').length < 1) {
        $('#status-description-field').after([
            '<div id="status-fields" class="dl_tbl dlg_scroll">', '</div>',
        ].join(''));
    }
    $('#status-fields').append([
        '<dl class="status-field-content">',
        '<dt>', '<span id="content_name">', '</span>','</dt>',
        '<dd id="progress-bar-', id, '" class="status-progress-bar">',
        '</dd>',
        '</dl>',
    ].join(''));
    $('dl:last-child span#content_name').text(name);
    this._progressBar.createProgressBar(['#progress-bar-', id].join(''));
    this.setProgressBar(['#progress-bar-', id].join(''), '0');
};

prototype.addReservationContents = function() {
    $('#status-fields').remove();
    this.finished();
};

prototype.addReservationDuplicateErrorContents = function() {
    this.setStatusDescription(_('contents_wizard_status_reservation_transfer_duplicate_error_contents'));
    $('#status-fields').remove();
    this.finished();
};

prototype.addErrorContents = function() {
    this.setStatusDescription(_('contents_wizard_status_download_error_contents'));
    $('#status-fields').remove();
    this.finished();
};

prototype.setRemainingTime = function(selector, time) {
    this._progressBar.setDescriptionFlag(true);
    this._progressBar.setRemainingTime(selector, time);
};

prototype.setProgressBar = function(selector, prog) {
    this._progressBar.setProgressBar(selector, prog);
};

prototype.errorProgressBar = function(selector) {
    this._progressBar.setDescriptionFlag(true);
    this._progressBar.errorProgressBar(selector);
};

prototype.unknownProgressBar = function(selector) {
    this._progressBar.setDescriptionFlag(false);
    $(selector).html([
        '<p>', _('status_progress_unknown_description'), '</p>',
        '<p>', '</p>',
    ].join(''));
};

prototype.unknownProgressBarDone = function() {
    this._progressBar.setDescriptionFlag(true);
};

prototype._clickCancel = function() {
    this.dispatchEvent(new Event(CANCEL));
};

prototype.finished = function() {
    this.setButtons([{
        text: _('dialog_close'),
        click: dixim.proxy(this.hide, this),
    }]);
};

}());
