/**
 * @module dixim
 * @submodule server
 */
dixim.namespace('dixim.server');

/**
 * @module server
 * @submodule parental-edit-setting-controller
 */

(function() {
var ParentalEditSettingController;
var prototype;
var superConstructor;
var ParentalEditSettingView = dixim.server.ParentalEditSettingView;
var EventTarget = dixim.event.EventTarget;
var _ = dixim.ctt.ResourceBundle.get;
var ApiClientTransfer = dixim.common.ApiClientTransfer;
var PinManager = dixim.ctt.util.PinManager;
var ErrorModalDialogView = dixim.common.ErrorModalDialogView;
var BlockUi = dixim.common.BlockUi;
var ConfirmModalDialogView = dixim.common.ConfirmModalDialogView;

/**
 * @class ParentalEditSettingController
 * @constructor
 * @param {Object} configs
 */
ParentalEditSettingController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(ParentalEditSettingController, EventTarget);
dixim.server.ParentalEditSettingController = ParentalEditSettingController;
prototype = ParentalEditSettingController.prototype;
superConstructor = ParentalEditSettingController.superConstructor;

var OK = 'ok';
var APPLY = 'apply';
var PREV = 'prev';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    this._id = [configs.id, 'parental-edit-setting'].join('');

    this._model = new ApiClientTransfer();
    this._model.addEventListener('fetchPin', this._successFetchPin, this);
    this._model.addEventListener('fetchPinError', this._errorFetchPin, this);
    this._model.addEventListener('setPin', this._successSetPin, this);
    this._model.addEventListener('setPinError', this._errorSetPin, this);

    this._view = new ParentalEditSettingView(configs);
    this._view.addEventListener(APPLY, this._clickApply, this);
    this._view.addEventListener(PREV, this._clickPrev, this);

    this._blockUi = new BlockUi();
    this._parentContext = configs.parentContext;
    this._pinCode = configs.pinCode;
    this._ageLimit = null;
};

/**
 * @method start
 */
prototype.start = function() {
    this._view.show();
    this._fetchPin();
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._fetchPin = function() {
    var query = {};

    this._blockUi.block();

    query.code = this._pinCode;
    this._model.fetchPin(query);
};

prototype._successFetchPin = function(e) {
    var ageLimit = e.args.age_limit;

    this._view.setValue(ageLimit);
    this._blockUi.unblock();
};

prototype._errorFetchPin = function(e) {
    this._view.setErrorValue();
    this._blockUi.unblock();
};

prototype._successSetPin = function () {
    PinManager.set((this._ageLimit === 17) ? this._pinCode : null)
    this._blockUi.unblock();
    this._fetchPin();
};

prototype._errorSetPin = function() {
    this._blockUi.unblock();
    this._errorDialog(_('server_parental_edit_setting_could_not_setting'));
};

prototype._errorDialog = function(text) {
    var query = {};
    var dialog;

    query.id = this._id;
    query.title = _('server_parental_menu_edit_setting_title');
    query.description = text;
    dialog = new ErrorModalDialogView(query);
    dialog.show();
};

prototype._clickApply = function(e) {
    var query = {};
    var dialog;
    var clickOk = dixim.proxy(function() {
        var query = {};

        dialog.hide();
        this._blockUi.block();

        this._ageLimit = e.args.ageLimit;

        query.code = this._pinCode;
        query.code_new = this._pinCode;
        query.age_limit = e.args.ageLimit;
        this._model.setPin(query);
    }, this);

    query.id = this._id;
    query.title = _('server_parental_menu_edit_setting_title');
    query.description = _('server_parental_edit_setting_confirm_description');
    dialog = new ConfirmModalDialogView(query);
    dialog.addEventListener(OK, clickOk, this);
    dialog.show();
};

prototype._clickPrev = function() {
    this.stop();
    this._parentContext.start();
};

}());
