/**
 * @module dixim
 * @submodule vdms
 */
dixim.namespace('dixim.vdms');

/**
 * @module vdms
 * @submodule deletion-dialog-controller
 */

(function() {
var DeletionDialogController;
var prototype;
var superConstructor;
var DeletionDialogView = dixim.vdms.DeletionDialogView;
var EventTarget = dixim.event.EventTarget;
var Event = dixim.event.Event;
var _ = dixim.ctt.ResourceBundle.get;
var ApiClientVdms = dixim.common.ApiClientVdms;
var ErrorModalDialogView = dixim.common.ErrorModalDialogView;

/**
 * @class DeletionDialogController
 * @constructor
 * @param {Object} configs
 */
DeletionDialogController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(DeletionDialogController, EventTarget);
dixim.vdms.DeletionDialogController = DeletionDialogController;
prototype = DeletionDialogController.prototype;
superConstructor = DeletionDialogController.superConstructor;

var YES = 'yes';
var COMPLETE = 'complete';
var CLOSE = 'close';
var UPDATE = 'update';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    this._id = [configs.id, 'deletion-dialog'].join('');

    this._model = new ApiClientVdms();
    this._model.addEventListener('removeAggregation', this._successRemove, this);
    this._model.addEventListener('removeAggregationError', this._errorRemove, this);

    this._view = new DeletionDialogView(configs);
    this._view.addEventListener(YES, this._clickYes, this);
    this._view.addEventListener(COMPLETE, this._complete, this);

    this._contents = configs.contents;
    this._isProcessError;
};

/**
 * @method start
 */
prototype.start = function() {
    this._view.show();
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._successRemove = function() {
    this._view.decrementDescription();
};

prototype._errorRemove = function() {
    this._isProcessError = true;
    this._view.decrementDescription();
};

prototype._deleteContents = function() {
    var contentsLen = this._contents.length;
    var query = {};

    this._isProcessError = false;
    for (var i = 0; i < contentsLen; i += 1) {
        query.udn = this._contents[i].udn;
        this._model.removeAggregation(query);
    }
};

prototype._complete = function() {
    this.stop();
    if (this._isProcessError) {
        this._errorDialog(_('vdms_aggregation_delete_error'));
        this.dispatchEvent(new Event(CLOSE));
    } else {
        this.dispatchEvent(new Event(UPDATE));
    }
};

prototype._clickYes = function() {
    this._deleteContents();
};

prototype._errorDialog = function(text) {
    var query = {};
    var dialog;

    query.id = this._id;
    query.title = _('vdms_aggregation_operation_delete');
    query.doubleDialog = true;
    query.description = text;
    dialog = new ErrorModalDialogView(query);
    dialog.show();
};

}());
