/**
 * @module ctt
 * @submodule schedule-entry-listing-wizard-page-view
 */
(function() {
var Event = dixim.event.Event;
var WizardPageView = dixim.ctt.WizardPageView;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;

var ScheduleEntryListingWizardPageView;
var prototype;
var superConstructor;

/**
 * @class ScheduleEntryListingWizardPageView
 * @extends ModalDialogView
 * @constructor
 * @param {Object} configs
 */
ScheduleEntryListingWizardPageView = function(configs) {
  WizardPageView.call(this, configs);
};
dixim.inherit(ScheduleEntryListingWizardPageView, WizardPageView);
dixim.ctt.ScheduleEntryListingWizardPageView = ScheduleEntryListingWizardPageView;
prototype = ScheduleEntryListingWizardPageView.prototype;
superConstructor = ScheduleEntryListingWizardPageView.superConstructor;

var TEMPLATE_CONTENT_BOX = '<div class="ctt-schedule-entry-listing-wizard-page-view-wrapper" />';

var TEMPLATE_BODY_CONTENT = ['<div class="ctt-schedule-entry-listing-wizard-page-view">',
                               '<div class="ctt-schedule-entry-listing-wizard-page-view-entery-list"></div>',
                               '<div class="ctt-schedule-entry-listing-wizard-page-view-message-wrapper">',
                                 '<div class="ctt-schedule-entry-listing-wizard-page-view-description"></div>',
                                 '<div class="ctt-schedule-entry-listing-wizard-page-view-error"></div>',
                               '</div>',
                             '</div>'].join('');

/**
 * Triggered when the close button was clicked.
 *
 * @event close
 */
var CLOSE = 'close';

/**
 * Triggered when the update button was clicked.
 *
 * @event update
 */
var UPDATE = 'update';

/**
 * Triggered when the delete button was clicked.
 *
 * @event delete
 */
var DELETE = 'delete';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
  var buttons;

  configs  = configs || {};

  buttons = [
    {
      'text': _('ctt_dialog_button_label_close'),
      click: $.proxy(this._didClickClose, this)
    },
    {
      'text': _('ctt_transfer_schedule_view_button_label_update'),
      click: $.proxy(this._didClickUpdate, this),
      align: 'left',
      'class': 'ctt-schedule-entry-listing-wizard-page-view-button-update'
    },
    {
      'text': _('ctt_transfer_schedule_view_button_label_delete'),
      click: $.proxy(this._didClickDelete, this),
      align: 'left',
      'class': 'ctt-schedule-entry-listing-wizard-page-view-button-delete'
    }
  ];

  configs.title = _('ctt_transfer_schedule_view_title');
  configs.contentBox = configs.contentBox || TEMPLATE_CONTENT_BOX;
  configs.bodyContent = configs.bodyContent || TEMPLATE_BODY_CONTENT;
  configs.buttons = buttons;

  superConstructor.prototype._initialize.call(this, configs);
};

prototype._didRenderDialog = function(e) {
  superConstructor.prototype._didRenderDialog.call(this, e);
};

prototype._didTitlebarCloseButtonClick = function(e) {
  e.preventDefault();
  this._closeDialog();
};

prototype._didClickClose = function(e) {
  this._closeDialog();
};

prototype._closeDialog = function() {
  this.dispatchEvent(new Event(CLOSE));
};

prototype._didClickUpdate = function(e) {
  this.dispatchEvent(new Event(UPDATE));
};

prototype._didClickDelete = function(e) {
  this.dispatchEvent(new Event(DELETE));
};

prototype.enableDeleteButton = function() {
  this.enableButton('.ctt-schedule-entry-listing-wizard-page-view-button-delete');
};

prototype.disableDeleteButton = function() {
  this.disableButton('.ctt-schedule-entry-listing-wizard-page-view-button-delete');
};

prototype.enableUpdateButton = function() {
  this.enableButton('.ctt-schedule-entry-listing-wizard-page-view-button-update');
};

prototype.disableUpdateButton = function() {
  this.disableButton('.ctt-schedule-entry-listing-wizard-page-view-button-update');
};

// TODO:
///**
// * @method showError
// * @param {ErrorCode} errorCode
// */
//prototype.showError = function(errorCode) {
//  this._showError(errorCode);
//};
//
//prototype._showError = function(errorCode) {
//  var key;
//
//  if (!!errorCode) {
//    key = ErrorMessage[errorCode] || 'ctt_transfer_schedule_view_error_unknown';
//    this._errorNode.text(_(key)).show();
//  } else {
//    this._errorNode.text('').hide();
//  }
//};
//
//// TODO: this is tentative indicator
//prototype.showActivityIndicator = function() {
//  if (this._inProgress) return;
//
//  this._inProgress = true;
//  this._descriptionNode.text(_('ctt_transfer_schedule_view_description_cleanup_in_progress'));
//};
//
//prototype.hideActivityIndicator = function() {
//  if (!this._inProgress) return;
//
//  this._inProgress = false;
//  this._descriptionNode.text('');
//};
//// TODO: ...end.
// TODO: ...end.

}());