/**
 * @module ctt
 * @submodule ctt-ad
 */
dixim.namespace('dixim.ctt.ad');

/**
 * @module ctt-ad
 * @submodule auto-download-tool-controller
 */
(function () {
var AutoDownloadApiClient = dixim.ctt.ad.AutoDownloadApiClient;
var AutoDownloadTaskListController = dixim.ctt.ad.AutoDownloadTaskListController;
var ToolbarView = dixim.ctt.ToolbarView;
var DeletionDialogController = dixim.ctt.ad.DeletionDialogController;
var SettingDialogController = dixim.ctt.ad.SettingDialogController;
var HistoryDialogController = dixim.ctt.ad.HistoryDialogController;
var SelectSrcContainerDialogController = dixim.ctt.ad.SelectSrcContainerDialogController;
var SelectDstContainerDialogController = dixim.ctt.ad.SelectDstContainerDialogController;
var SelectHowtoDownloadDialogController = dixim.ctt.ad.SelectHowtoDownloadDialogController;
var SelectHowtoDownloadDialogEditController = dixim.ctt.ad.SelectHowtoDownloadDialogEditController;
var FilterListDialogController = dixim.ctt.ad.FilterListDialogController;
var ErrorDialog = dixim.ctt.ErrorDialog;
var _ = dixim.ctt.ResourceBundle.get;

var AutoDownloadToolController;
var prototype;

/**
 * Root controller of the Automatic Download Move-in Tool.
 *
 * @class AutoDownloadToolController
 * @constructor
 * @param {Object} configs config object.
 * @param {String} configs.containerNode an ID of the tool container. (ex: '#container', '#wrapper')
 */
AutoDownloadToolController = function(configs) {
  this._initialize(configs);
};
dixim.ctt.ad.AutoDownloadToolController = AutoDownloadToolController;
prototype = AutoDownloadToolController.prototype;

/**
 * @method _initialize
 * @protected
 * @param {Object} configs config object.
 * @param {String} configs.containerNode
 */
prototype._initialize = function(configs) {
  this._modal = null;
  this._model = new AutoDownloadApiClient();
  this._containerNode = configs.containerNode;

  this._appToolbar = new ToolbarView({
    containerNode: '#app-toolbar',
    buttons: [
      {
        id: 'settings',
        label: _('ctt_toolbar_button_settings')
      },
      {
        id: 'filter',
        label: _('ctt_toolbar_button_filter')
      },
      {
        id: 'history',
        label: _('ctt_toolbar_button_history'),
        align: 'right'
      }
    ]
  });

  this._taskListToolbar = new ToolbarView({
    containerNode: '#task-list-toolbar',
    buttons: [
      {
        id: 'edit',
        label: _('ctt_toolbar_button_edit')
      },
      {
        id: 'delete',
        label: _('ctt_toolbar_button_delete')
      },
      {
        id: 'select_all',
        label: _('ctt_toolbar_button_select_all')
      },
      {
        id: 'unselect_all',
        label: _('ctt_toolbar_button_unselect_all')
      },
      {
        id: 'add',
        label: _('ctt_toolbar_button_add'),
        align: 'right'
      }
    ]
  });

  this._taskListController = new AutoDownloadTaskListController({
    containerNode: '#task-list-table',
    model: this._model
  });
};

/**
 * @method start
 */
prototype.start = function() {
  this._setEventListeners();
  this._taskListToolbar.show();
  this._appToolbar.show();
  this._taskListController.start();
};

var mock = function(e) {
  console.log(e);
};

var _didClickAdd = function() {
  var add_data = {};
  var select_src_container_dialog = new SelectSrcContainerDialogController();
  var select_src_container_query = {};

  select_src_container_query.finish = dixim.proxy(function(e) {
    var select_dst_container_dialog = new SelectDstContainerDialogController();
    var select_dst_container_query = {};

    select_dst_container_query.finish = dixim.proxy(function(e) {
      var select_howto_download_dialog;
      var select_howto_download_query = {};

      select_howto_download_query.finish = dixim.proxy(function(e) {
        var task_add_query;
        var select_info = e;

        $.extend(add_data, select_info);
        task_add_query = {
            srcUdn: add_data.srcUdn,
            srcContainerId: add_data.srcContainerId,
            dstContainerId: add_data.dstContainerId,
            sdFirst: add_data.sdFirst,
            reservationType: add_data.reservationType
         };

        if (typeof add_data.timedReservationStartTime !== "undefined") {
          task_add_query.timedReservationStartTime = add_data.timedReservationStartTime;
         }

        task_add_query.success = dixim.proxy(function(e) {
          var taskId = e.args.taskId;
          var filter_length = select_info.filterList.length;
          var task_link_query = {};

          this._taskListController.reload();
          task_link_query.taskId = taskId;
          for(var i = 0; i < filter_length; i += 1) {
            task_link_query.filterId = parseInt(select_info.filterList[i], 10);
            this._model.linkFilter(task_link_query);
           }
        }, this);
        task_add_query.error = dixim.proxy(function(e) {
          var errorCode = e.args.errorCode;
          var error_description = _(["ctt_ad_error_",errorCode].join(''));

          if (error_description.substr(0,13) === "[ctt_ad_error_") {
            error_description = _("ctt_ad_error_other");
           }

          this._showErrorDialog({title: _("ctt_error_dialog_default_title"),description: error_description});
        }, this);

        this._model.addTask(task_add_query);
       }, this);

      select_howto_download_query.back = dixim.proxy(function() {
        select_dst_container_dialog.start(select_dst_container_query);
      }, this);

      $.extend(add_data, e);
      select_howto_download_dialog = new SelectHowtoDownloadDialogController(select_howto_download_query);
      select_howto_download_dialog.start();

    }, this);

    select_dst_container_query.back = dixim.proxy(function() {
      select_src_container_dialog.start(select_src_container_query);
    }, this);

    $.extend(add_data, e);
    select_dst_container_dialog.start(select_dst_container_query);
  }, this);

  select_src_container_dialog.start(select_src_container_query);
};

var _didClickDelete = function() {
  var query = this._taskListController.getSelectedRows();
  var finished_reload;
  var vc;

  if (query.length < 1) {
    this._showErrorDialog("error_dialog_delete_task");
    return;
  }
  finished_reload = dixim.proxy(function() {
    this._taskListController.reload();
  }, this);
  vc = new DeletionDialogController({
    targetItems: query,
    model: this._model,
    finish: finished_reload,
    thingsToDelete: "task",
    description: 'ctt_task_deletion_view_description'
  });
  vc.start();
};

var _didClickSelectAll = function() {
  $("input:checkbox[name='rowSelector']").prop("checked", true);
};

var _didClickUnselectAll = function() {
  $("input:checkbox[name='rowSelector']:checked").prop("checked", false);
};

var _didClickSettings = function() {
  var setting_dialog = new SettingDialogController();
  setting_dialog.start();
};

var _didClickHistory = function() {
  var history_dialog = new HistoryDialogController();
  history_dialog.start();
};

var _didClickFilter = function() {
  var finished_reload = dixim.proxy(function() {
    this._taskListController.reload();
  }, this);
  var fld = new FilterListDialogController({
    finish: finished_reload
  });
  fld.start();
};

var _didClickEdit = function() {
  var edit_task_query = {};
  var select =  this._taskListController.getSelectedRows();
  var edit_task_dialog;

  if (select.length === 1) {
    edit_task_query.finish = dixim.proxy(function() {
      this._taskListController.reload();
    }, this);
    edit_task_query.select = select[0];
    edit_task_dialog = new SelectHowtoDownloadDialogEditController(edit_task_query);
    edit_task_dialog.start();
  } else {
    prototype._showErrorDialog("ctt_error_dialog_to_change_select_no_task");
  }
};

prototype._setEventListeners = function() {
  this._taskListToolbar.addEventListener('add', _didClickAdd, this);
  this._taskListToolbar.addEventListener('edit', _didClickEdit, this);
  this._taskListToolbar.addEventListener('delete', _didClickDelete, this);
  this._taskListToolbar.addEventListener('select_all', _didClickSelectAll, this);
  this._taskListToolbar.addEventListener('unselect_all', _didClickUnselectAll, this);
  this._appToolbar.addEventListener('settings', _didClickSettings, this);
  this._appToolbar.addEventListener('filter', _didClickFilter, this);
  this._appToolbar.addEventListener('history', _didClickHistory, this);
  this._taskListController.addEventListener('changeSelection', mock, this);
  this._taskListController.addEventListener('loadTaskList', mock, this);
};

/**
 * @method _showErrorDialog
 * @private
 * @param {String} error error ID.
 */
prototype._showErrorDialog = function(error) {
  var dialog;
  var query = {type: error};

  if (!!this._modal) {
    this._modal.destroy();
    this._modal = null;
  }
  if (typeof error.title !== "undefined") {
    query.title = error.title;
  }
  if (typeof error.description !== "undefined") {
    query.description = error.description;
  }

  dialog = new ErrorDialog(query);
  dialog.addEventListener('close', this._didCloseModalDialog, this);

  dialog.show();
  this._modal = dialog;
};

prototype._didCloseModalDialog = function(e) {
  var args = e.args;

  if (this._modal === args.dialog) {
    this._modal.destroy();
    this._modal = null;
  }
};

/**
 * @method stop
 */
prototype.stop = function() {
};

}());