/**
 * @module dixim
 * @submodule common 
 */
dixim.namespace('dixim.common');

/**
 * @module common
 * @submodule home-menu-controller
 */

(function() {
var HomeMenuController;
var prototype;
var superConstructor;
var HomeMenuView = dixim.common.HomeMenuView;
var EventTarget = dixim.event.EventTarget;
var UiFunctionManager = dixim.ctt.util.UiFunctionManager;
var Configs = dixim.ctt.Configs;

/**
 * @class HomeMenuController
 * @constructor
 * @param {Object} configs
 */
HomeMenuController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(HomeMenuController, EventTarget);
dixim.common.HomeMenuController = HomeMenuController;
prototype = HomeMenuController.prototype;
superConstructor = HomeMenuController.superConstructor;

UiFunctionManager.set('home');

var MENU = 'menu';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    this._view = new HomeMenuView(configs);
    this._view.addEventListener(MENU, this._clickMenu, this);

    this._menuList = [];

    if (UiFunctionManager.isImplement('home')) {
        this._menuList.push({
            id: 'home',
            class: 'ico_nav_home',
            titleId: 'common_menu_title_home',
            isOnRoot: false,
        });
    }

    if (UiFunctionManager.isImplement('server')) {
        this._menuList.push({
            id: 'server',
            class: 'ico_nav_server',
            titleId: 'common_menu_title_server',
            image: [Configs.get('imagePath'), '/ico_hm_server.png'].join(''),
            isOnRoot: true,
            descriptionId: 'common_menu_description_server',
        });
    }

    if (UiFunctionManager.isImplement('contents')) {
        this._menuList.push({
            id: 'contents',
            class: 'ico_nav_cont',
            titleId: 'common_menu_title_contents',
            image: [Configs.get('imagePath'), '/ico_hm_cont.png'].join(''),
            isOnRoot: true,
            descriptionId: 'common_menu_description_contents',
        });
    }

    if (UiFunctionManager.isImplement('download')) {
        this._menuList.push({
            id: 'download',
            class: 'ico_nav_dl',
            titleId: 'common_menu_title_download',
            image: [Configs.get('imagePath'), '/ico_hm_dl.png'].join(''),
            isOnRoot: true,
            descriptionId: 'common_menu_description_download',
        });
    }
};

/**
 * @method start
 */
prototype.start = function() {
    var menuListLen = this._menuList.length;

    this._view.show();

    for (var i = 0; i < menuListLen; i += 1) {
        this._view.addSidebarMenu(this._menuList[i]);
    }
    this._createRootPage();
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._createRootPage = function() {
    var menuListLen = this._menuList.length;

    this._view.addRootBase();
    for (var i = 0; i < menuListLen; i += 1) {
        if (this._menuList[i].isOnRoot) this._view.addRootPageMenu(this._menuList[i]);
    }
    this._view.setEffect();
};

prototype._clickMenu = function(e) {
    var controller;
    var query = {};

    switch(e.args.id) {
        case 'home':
            this._updateRootPage();
            return;
        case 'server':
            query.parentContext = this;
            controller = new dixim.server.ServerMenuController(query);
            break;
        case 'contents':
            query.parentContext = this;
            controller = new dixim.contents.ContentsMenuController(query);
            break;
        case 'download':
            query.parentContext = this;
            controller = new dixim.download.DownloadMenuController(query);
            break;
        default:
            this._updateRootPage();
            return;
    }
    controller.start();
};

prototype._updateRootPage = function() {
    this._view.cleanRootPage();
    this._createRootPage();
};

}());
