/**
 * @module dixim
 * @submodule contents
 */
dixim.namespace('dixim.contents');

/**
 * @module contents
 * @submodule operation-menu-dialog-controller
 */

(function() {
var OperationMenuDialogController;
var prototype;
var superConstructor;
var OperationMenuDialogView = dixim.contents.OperationMenuDialogView;
var EventTarget = dixim.event.EventTarget;
var Event = dixim.event.Event;
var _ = dixim.ctt.ResourceBundle.get;
var ErrorModalDialogView = dixim.common.ErrorModalDialogView;
var RenameDialogController = dixim.contents.RenameDialogController;
var MoveDialogController = dixim.contents.MoveDialogController;
var MkdirDialogController = dixim.contents.MkdirDialogController;
var DeletionDialogController = dixim.contents.DeletionDialogController;

/**
 * @class OperationMenuDialogController
 * @constructor
 * @param {Object} configs
 */
OperationMenuDialogController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(OperationMenuDialogController, EventTarget);
dixim.contents.OperationMenuDialogController = OperationMenuDialogController;
prototype = OperationMenuDialogController.prototype;
superConstructor = OperationMenuDialogController.superConstructor;

var DELETE = 'delete';
var RENAME = 'rename';
var MOVE = 'move';
var MKDIR = 'mkdir';
var UPDATE = 'update';
var CLOSE = 'close';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    this._id = [configs.id, 'operation-menu-dialog'].join('');

    this._view = new OperationMenuDialogView(configs);
    this._view.addEventListener(DELETE, this._clickDelete, this);
    this._view.addEventListener(RENAME, this._clickRename, this);
    this._view.addEventListener(MOVE, this._clickMove, this);
    this._view.addEventListener(MKDIR, this._clickMkdir, this);

    this._dataList = configs.dataList || [];
    this._parentId = configs.parentId;
};

/**
 * @method start
 */
prototype.start = function() {
    this._view.show();
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._clickDelete = function() {
    var controller;
    var query = {};

    if (this._dataList.length === 0) {
        this._errorDialog(_('contents_operation_menu_delete'), _('contents_operation_menu_error_no_selected'))
        return;
    }
    query.contents = this._dataList;
    query.doubleDialog = true;
    controller = new DeletionDialogController(query);
    controller.addEventListener(UPDATE, this._callbackUpdate, this);
    controller.start();
};

prototype._clickRename = function() {
    var controller;
    var query = {};

    if (this._dataList.length !== 1) {
        this._errorDialog(_('contents_operation_menu_rename'), _('contents_operation_menu_error_not_one'))
        return;
    }
    query.targetItem = this._dataList[0];
    query.doubleDialog = true;
    controller = new RenameDialogController(query);
    controller.addEventListener(UPDATE, this._callbackUpdate, this);
    controller.start();
};

prototype._clickMove = function() {
    var controller;
    var query = {};

    if (this._dataList.length === 0) {
            this._errorDialog(_('contents_operation_menu_move'), _('contents_operation_menu_error_no_selected'))
        return;
    }
    query.contents = this._dataList;
    query.doubleDialog = true;
    controller = new MoveDialogController(query);
    controller.addEventListener(UPDATE, this._callbackUpdate, this);
    controller.start();
};

prototype._clickMkdir = function() {
    var controller;
    var query = {};

    query.doubleDialog = true;
    query.parentId = this._parentId;
    controller = new MkdirDialogController(query);
    controller.addEventListener(UPDATE, this._callbackUpdate, this);
    controller.start();
};

prototype._callbackUpdate = function() {
    this.stop();
    this.dispatchEvent(new Event(UPDATE));
};

prototype._errorDialog = function(title, text) {
    var dialog;
    var query = {};

    query.id = this._id;
    query.title = title;
    query.description = text;
    query.doubleDialog = true;
    dialog = new ErrorModalDialogView(query);
    dialog.show();
};

}());
