/**
 * @module dixim
 * @submodule server
 */
dixim.namespace('dixim.server');

/**
 * @module server
 * @submodule extensions-edit-dialog-view
 */

(function() {
var ExtensionsEditDialogView;
var prototype;
var superConstructor;
var ModalDialogView = dixim.common.ModalDialogView;
var Event = dixim.event.Event;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;

/**
 * @class ExtensionsEditDialogView
 * @constructor
 * @param {Object} configs
 */
ExtensionsEditDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(ExtensionsEditDialogView, ModalDialogView);
dixim.server.ExtensionsEditDialogView = ExtensionsEditDialogView;
prototype = ExtensionsEditDialogView.prototype;
superConstructor = ExtensionsEditDialogView.superConstructor;

var CLOSE = 'close';
var OK = 'ok';

var TEMPLATE_BODY_CONTENT = [
    '<div class="dlg_main_msg">', '${description}', '</div>',
    '<div class="dlg_scroll dl_tbl">',
    '<dl>', '<dt>', '${extension}', '</dt>',
    '<dd>', '<input type="text" id="extensions_edit_dialog_extension" maxlength="255" />', '</dd>',
    '</dl>',
    '<dl>', '<dt>', '${mimetype}', '</dt>',
    '<dd>', '<input type="text" id="extensions_edit_dialog_mimetype" maxlength="255" />', '</dd>',
    '</dl>',
    '</div>',
].join('');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'extensions-edit-dialog-'].join('');

    this._itemData = configs.itemData || null;

    configs.bodyContent = TEMPLATE_BODY_CONTENT.
        replace('${description}', _('server_extension_dialog_description')).
        replace('${extension}', _('server_extension_dialog_extension')).
        replace('${mimetype}', _('server_extension_dialog_mimetype'));

    configs.title = (this._itemData === null) ? _('server_extension_dialog_add_title') : _('server_extension_dialog_edit_title');
    configs.contentHeight = '230px';
    configs.closeButton = dixim.proxy(this.hide, this);
    configs.buttons = [
        {
            text: _('dialog_close'),
            click: dixim.proxy(this.hide, this),
        },
        {
            text: (this._itemData === null) ? _('dialog_add') : _('dialog_edit'),
            click: dixim.proxy(this._clickOk, this),
        },
    ];

    superConstructor.prototype._initialize.call(this, configs);
};

/**
 * @method show
 */
prototype.show = function() {
    superConstructor.prototype.show.call(this);

    if (this._itemData === null) return;

    $('#extensions_edit_dialog_extension').val(this._itemData.extension);
    $('#extensions_edit_dialog_mimetype').val(this._itemData.mimeType);
};

prototype._clickOk = function() {
    var data = {};

    data.extension = $('#extensions_edit_dialog_extension').val();
    data.mimetype = $('#extensions_edit_dialog_mimetype').val();
    this.dispatchEvent(new Event(OK, data));
};

}());
